@@ -15,12 +15,12 @@ def dag_02():
     d = h(y=b, c=c)
 
 
-_string01 = '''a -> g -> c
-a -> f -> b
+_string01 = '''a -> f -> b
+a -> g -> c
 b,c -> h -> d'''
 
-_string02 = '''x=a -> g -> c
-a -> f -> b
+_string02 = '''a -> f -> b
+x=a -> g -> c
 y=b,c -> h -> d'''
 
 
